# py-sidif
SiDIF (Simple Data Interchange Format) parser

[![Documentation Status](https://readthedocs.org/projects/py-sidif/badge/?version=latest)](https://py-sidif.readthedocs.io/en/latest/?badge=latest)
[![pypi](https://img.shields.io/pypi/pyversions/py-sidif)](https://pypi.org/project/py-sidif/)
[![Github Actions Build](https://github.com/WolfgangFahl/py-sidif/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/py-sidif/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/py-sidif.svg)](https://pypi.python.org/pypi/py-sidif/)
[![Downloads](https://pepy.tech/badge/py-sidif)](https://pepy.tech/project/py-sidif)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/py-sidif.svg)](https://github.com/WolfgangFahl/py-sidif/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/py-sidif.svg)](https://github.com/WolfgangFahl/py-sidif/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/py-sidif.svg)](https://www.apache.org/licenses/LICENSE-2.0)

What it is
==========
Parser for Simple Data Interchange Format [SiDIF](http://wiki.bitplan.com/index.php/SiDIF) 

Installation
============
```bash
pip install py-sidif
```

Get Sources
===========
```bash
git clone https://github.com/WolfgangFahl/py-sidif
cd py-sidif
scripts/install
```

Testing
=======
```bash
scripts/test
```

Usage
=====
see [test cases](https://github.com/WolfgangFahl/py-sidif/tree/main/tests)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/py-sidif)

### Authors
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)
